pm4py.statistics.start\_activities package
==========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.statistics.start_activities.common
   pm4py.statistics.start_activities.log
   pm4py.statistics.start_activities.pandas

Module contents
---------------

.. automodule:: pm4py.statistics.start_activities
   :members:
   :undoc-members:
   :show-inheritance:
